#!/usr/bin/php
<?php
/*
* 1. Adds a 'no-milestone' label to any issues with no milestone
* 2. Removes the 'no-milestone' label if present on an issue with a milestone
* 3. Adds a 'no-label' label to any issues with no labels (excluding 'no-label' and 'no-milestone')
* 4. Removes the 'no-label' label if present on an issue with a label (excluding 'no-label' and 'no-milestone')
*/

// load the config, create the connection and load the repo sepcified on the cmd line args
// we will then have $client and $repo available
require 'setup.php';

//get the labels of interest
$nolabelLabel = $repo->getLabelByName('no-label');
if (!$nolabelLabel) {
    die("Can't find 'no-label' label in repo\n");
}

$nomilestoneLabel = $repo->getLabelByName('no-milestone');
if (!$nomilestoneLabel) {
    die("Can't find 'no-milestone' label in repo\n");
}

//define the function to process each issue
$callback = function ($issue) use ($nolabelLabel,$nomilestoneLabel) {
    // do the no-label thing
    $labelCount = count($issue->labels);
    if ($issue->hasLabel($nolabelLabel)) {
        --$labelCount;
    }
    //dont count the no-label label
    if ($nomilestoneLabel && $issue->hasLabel($nomilestoneLabel)) {
        --$labelCount;
    }
    //dont count the no-milestone label
    if (0 == $labelCount && !$issue->hasLabel($nolabelLabel)) {
        $issue->addLabel($nolabelLabel);
    } elseif ($labelCount > 0 && $issue->hasLabel($nolabelLabel)) {
        $issue->removeLabel($nolabelLabel);
    }
    //do the no-milestone thing
    if (!$issue->milestone && !$issue->hasLabel($nomilestoneLabel)) {
        $issue->addLabel($nomilestoneLabel);
    } elseif ($issue->milestone && $issue->hasLabel($nomilestoneLabel)) {
        $issue->removeLabel($nomilestoneLabel);
    }
};

//loop through all issues and call the callback
$repo->forIssues($callback);
