#!/usr/bin/php
<?php
/*
* Creats a csv report of times spend on issues for
* a specific month of a specific user.
*/

require __DIR__.'/../vendor/autoload.php';

use JHodges\GiteaBot\Client;

$config = require __DIR__.'/config.php';

echo "Enter username for report: ";
$name = trim(fgets(STDIN)); // read from stdin

echo "Enter password: ";
$pass = trim(fgets(STDIN)); // read from stdin

echo "Enter month for report (0 = this, 1 = last, ...): ";
$ago = (int)(trim(fgets(STDIN))); // read from stdin
$date_start = date('Y-m-01', strtotime("now -$ago month"));
$date_end = date('Y-m-t', strtotime("now -$ago month"));

echo "Generateing report of time spent between $date_start - $date_end by $name...\n";

//open connection and repo
$client = new Client($config['url'], $name, $pass, $debug=true);

// process and sum up all the times by issue number
// (not ID as retrned by API)
$totals = [];
foreach ($client->getCurrentUserTimes(new \DateTime("{$date_start} 00:00:00") , new \DateTime("{$date_end} 23:59:59")) as $time) {
    // if we've not already got a total for this issue
    // then create the entry, looking up issue title
    if (!isset($totals[$time->issue->repository->full_name][$time->issue->number])) {
        $totals[$time->issue->repository->full_name][$time->issue->number] = [
            'repo'=> $time->issue->repository->full_name,
            'id' => $time->issue->number,
            'name' => $time->issue->title,
            'time' => 0,
        ];
    }
    // add the time to the total
    $totals[$time->issue->repository->full_name][$time->issue->number]['time'] += $time->time;
}

// helper to format seconds into H:M:S format
function format_time($t)
{
    return sprintf('%02d:%02d:%02d', floor($t / 3600), ($t / 60) % 60, $t % 60);
}

// save the report
$f = fopen('report.csv', 'w');
// ouput headers
fputcsv($f, ['Repo', 'ID', 'Description', 'Hours', 'H:M:S']);
// output data
foreach ($totals as $total){
  foreach ($total as $id => $data) {
      $data['hours'] = $data['time']/60/60; //decimal hours
      $data['hms'] = format_time($data['time']); //H:M:S
      unset($data['time']); //dont want seconds in the report
      fputcsv($f, $data);
  }
}
fclose($f);
echo "Saved as report.csv\n";
